# csv_db_package
Package having the local server module to upload a csv file and perform CRUD operations on the data shown using different features through database.

## Installation
pip install csv_db_package

---
### STEPS TO INSTALL & MODIFY THE PROJECT 
-Activate your python venv
-Install the requirements given:
    python
    pip install -r requirements.txt
    
Mysql is used as a database engine here.
-Set env variables
  <br/>`$env:HOST= your hostname for mysql`
  <br/>`$env:USER= your username`
  <br/>`$env:PASSWORD= your password`

-Run server inside directory by using command
python fileserver.py

-example table

| First column | Second column |                                    |
|--------------|---------------|------------------------------------|
| Content Cell | Content Cell  | [update](#update "Goto heading-1") |
| Content Cell | Content Cell  | [update](#update "Goto heading-1") |


___
© 2022 Ankita Liya

This repository is licensed under the MIT license. See LICENSE for details.

